package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcPartner;

/**
 * cmc合作单位Mapper接口
 * 
 * @author cmc
 * @date 2024-04-18
 */
public interface CmcPartnerMapper 
{
    /**
     * 查询cmc合作单位
     * 
     * @param partnerId cmc合作单位主键
     * @return cmc合作单位
     */
    public CmcPartner selectCmcPartnerByPartnerId(String partnerId);

    /**
     * 查询cmc合作单位列表
     * 
     * @param cmcPartner cmc合作单位
     * @return cmc合作单位集合
     */
    public List<CmcPartner> selectCmcPartnerList(CmcPartner cmcPartner);

    /**
     * 新增cmc合作单位
     * 
     * @param cmcPartner cmc合作单位
     * @return 结果
     */
    public int insertCmcPartner(CmcPartner cmcPartner);

    /**
     * 修改cmc合作单位
     * 
     * @param cmcPartner cmc合作单位
     * @return 结果
     */
    public int updateCmcPartner(CmcPartner cmcPartner);

    /**
     * 删除cmc合作单位
     * 
     * @param partnerId cmc合作单位主键
     * @return 结果
     */
    public int deleteCmcPartnerByPartnerId(String partnerId);

    /**
     * 批量删除cmc合作单位
     * 
     * @param partnerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcPartnerByPartnerIds(String[] partnerIds);
}
